function [c,b] = solv_quin(l1, l2, N)
% solution for symmetric quincunx lifting filters
% for certain number of vanishing moments
% input:  l1, l2 -- half of the filter length in the two dimensions 
%              N -- number of vanishing moments (should be even)
% output:    c,b -- coefficients of the linear system 
% e.g., [c,b] = solv_quin(2, 2, 4)
% Copyright (c) 2006 Yi Chen

row = N*(N+1)/2;
column = 2*l1*l2;
c = zeros(row, column);
b = zeros(row, 1);

row = 1;
for n1 = 0:N-1
    for n2 = 0:N-1-n1
        for k1 = 0:l1-1
            for k2 = -l2:l2-1
                column = 2*k1*l2 + k2 + l2 + 1;
                c(row, column) = (-k1)^n1*(-k2)^n2 + (1+k1)^n1*(1+k2)^n2;
            end
        end
        b(row) = 1/(2^(n1+n2));
        row = row+1;
    end
end